==> xl-react-components-0.16.62.tgz: package/tests/e2e/scenario/dip/xl-dip-list-of-ci-scenario.js <==
import R from 'ramda';
import Navigation from '../../dsl/common/navigation';
import TestBindings from '../../dsl/common/test-bindings';
import DipListOfCi from '../../dsl/component/dip/dip-list-of-ci';

describe('XL DIP List Of Ci Scenario', () => {
    afterAll(() => TestBindings.resetPristinity());
    beforeAll(() => Navigation.openDipElement('dipListOfCi1'));

    it('should have right initial state', () => {
        TestBindings.expectModelToEqual('["Item 1","Item 2","Item 3","Item 4","Item 5"]');
        TestBindings.expectPristineToEqual('true');
        TestBindings.expectValidToEqual('true');
        DipListOfCi.expectLabel('List of CIs');
        DipListOfCi.expectDescription('Find the description here');

        for (const index of R.range(1, 6)) {
            DipListOfCi.expectSelectedItemToEqual(index, `Item ${index}`);
            DipListOfCi.expectClearIconOfItemToBePresent(index);
        }

        DipListOfCi.expectSelectItemNotPresent(6);
    });

    it('should allow to add and remove elements (allow duplicates)', () => {
        DipListOfCi.openSelection();
        DipListOfCi.expectSuggestionListIsPresent();

        for (const index of R.range(1, 6)) {
            DipListOfCi.expectSuggestionValue(index, `Application${index}`);
        }

        DipListOfCi.selectOption(1);
        DipListOfCi.openSelection();
        DipListOfCi.expectSuggestionValue(2, 'Application2');
        DipListOfCi.selectOption(2);
        DipListOfCi.openSelection();
        DipListOfCi.selectOption(2);
        DipListOfCi.expectSuggestionListNotPresent();
        DipListOfCi.expectValue('');
        TestBindings.expectModelToEqual(
            '["Item 1","Item 2","Item 3","Item 4","Item 5","Application1","Application2","Application2"]');

        for (const index of R.range(1, 6)) {
            DipListOfCi.expectSelectedItemToEqual(index, `Item ${index}`);
        }

        DipListOfCi.expectSelectedItemToEqual(6, 'Application1');
        DipListOfCi.expectSelectedItemToEqual(7, 'Application2');
        DipListOfCi.expectSelectedItemToEqual(8, 'Application2');

        DipListOfCi.removeSelectedItem(8);
        DipListOfCi.removeSelectedItem(7);
        DipListOfCi.removeSelectedItem(3);

        DipListOfCi.expectSelectedItemToEqual(1, 'Item 1');
        DipListOfCi.expectSelectedItemToEqual(2, 'Item 2');
        DipListOfCi.expectSelectedItemToEqual(3, 'Item 4');
        DipListOfCi.expectSelectedItemToEqual(4, 'Item 5');
        DipListOfCi.expectSelectedItemToEqual(5, 'Application1');
        DipListOfCi.expectSelectItemNotPresent(6);

        TestBindings.expectModelToEqual('["Item 1","Item 2","Item 4","Item 5","Application1"]');
    });

    it('should allow to filter elements and remove them while filtered', () => {
        DipListOfCi.setFilter('1');
        DipListOfCi.expectSelectedItemToEqual(1, 'Item 1');
        DipListOfCi.expectSelectedItemToEqual(2, 'Application1');
        DipListOfCi.expectSelectItemNotPresent(3);
        TestBindings.expectModelToEqual('["Item 1","Item 2","Item 4","Item 5","Application1"]');

        DipListOfCi.removeSelectedItem(2);
        DipListOfCi.expectSelectedItemToEqual(1, 'Item 1');
        DipListOfCi.expectSelectItemNotPresent(2);
        TestBindings.expectModelToEqual('["Item 1","Item 2","Item 4","Item 5"]');
        DipListOfCi.clearFilter();

        DipListOfCi.expectSelectedItemToEqual(1, 'Item 1');
        DipListOfCi.expectSelectedItemToEqual(2, 'Item 2');
        DipListOfCi.expectSelectedItemToEqual(3, 'Item 4');
        DipListOfCi.expectSelectedItemToEqual(4, 'Item 5');
        DipListOfCi.expectSelectItemNotPresent(5);
    });

    it('should disable elements in disabled mode but still allow to search', () => {
        DipListOfCi.expectEnabled();
        TestBindings.toggleDisabled();
        DipListOfCi.expectClearIconOfItemToBeNotPresent(1);
        DipListOfCi.expectFilterEnabled();
        DipListOfCi.expectDisabled();
        TestBindings.toggleDisabled();
        DipListOfCi.expectEnabled();
    });

    it('should properly render different view modes', () => {
        TestBindings.displayModeDisplay();
        DipListOfCi.expectClearIconOfItemToBeNotPresent(1);
        DipListOfCi.expectFilterEnabled();
        DipListOfCi.expectDisabled();
        TestBindings.displayModeCreation();
        DipListOfCi.expectClearIconOfItemToBePresent(1);
        DipListOfCi.expectFilterEnabled();
        DipListOfCi.expectEnabled();
        TestBindings.displayModeEdit();
        DipListOfCi.expectClearIconOfItemToBePresent(1);
        DipListOfCi.expectFilterEnabled();
        DipListOfCi.expectEnabled();
    });
});

==> xl-react-components-0.21.9.tgz: package/tests/e2e/scenario/dip/xl-dip-list-of-ci-scenario.js <==
import R from 'ramda';
import Navigation from '../../dsl/common/navigation';
import TestBindings from '../../dsl/common/test-bindings';
import DipListOfCi from '../../dsl/component/dip/dip-list-of-ci';

describe('XL DIP List Of Ci Scenario', () => {
    afterAll(() => TestBindings.resetPristinity());
    beforeAll(() => Navigation.openDipElement('dipListOfCi1'));

    it('should have right initial state', () => {
        TestBindings.expectModelToEqual('["Item 1","Item 2","Item 3","Item 4","Item 5"]');
        TestBindings.expectPristineToEqual('true');
        TestBindings.expectValidToEqual('true');
        DipListOfCi.expectLabel('List of CIs');
        DipListOfCi.expectDescription('Find the description here');

        for (const index of R.range(1, 6)) {
            DipListOfCi.expectSelectedItemToEqual(index, `Item ${index}`);
            DipListOfCi.expectClearIconOfItemToBePresent(index);
        }

        DipListOfCi.expectSelectedItemNotPresent(6);
    });

    it('should allow to add and remove elements (allow duplicates)', () => {
        DipListOfCi.openSelection();
        DipListOfCi.expectSuggestionListIsPresent();

        for (const index of R.range(1, 6)) {
            DipListOfCi.expectSuggestionValue(index, `Application${index}`);
        }

        DipListOfCi.selectOption(1);
        DipListOfCi.expectValidItem(1);
        DipListOfCi.expectInvalidItem(6);
        DipListOfCi.openSelection();
        DipListOfCi.expectSuggestionValue(2, 'Application2');
        DipListOfCi.selectOption(2);
        DipListOfCi.openSelection();
        DipListOfCi.selectOption(2);
        DipListOfCi.expectSuggestionListNotPresent();
        DipListOfCi.expectValue('');
        TestBindings.expectModelToEqual(
            '["Item 1","Item 2","Item 3","Item 4","Item 5","Application1","Application2","Application2"]');

        for (const index of R.range(1, 6)) {
            DipListOfCi.expectSelectedItemToEqual(index, `Item ${index}`);
        }

        DipListOfCi.expectSelectedItemToEqual(6, 'Application1');
        DipListOfCi.expectSelectedItemToEqual(7, 'Application2');
        DipListOfCi.expectSelectedItemToEqual(8, 'Application2');

        DipListOfCi.removeSelectedItem(8);
        DipListOfCi.removeSelectedItem(7);
        DipListOfCi.removeSelectedItem(3);

        DipListOfCi.expectSelectedItemToEqual(1, 'Item 1');
        DipListOfCi.expectSelectedItemToEqual(2, 'Item 2');
        DipListOfCi.expectSelectedItemToEqual(3, 'Item 4');
        DipListOfCi.expectSelectedItemToEqual(4, 'Item 5');
        DipListOfCi.expectSelectedItemToEqual(5, 'Application1');
        DipListOfCi.expectSelectedItemNotPresent(6);

        TestBindings.expectModelToEqual('["Item 1","Item 2","Item 4","Item 5","Application1"]');
    });

    it('should allow to filter elements and remove them while filtered', () => {
        DipListOfCi.setFilter('1');
        DipListOfCi.expectSelectedItemToEqual(1, 'Item 1');
        DipListOfCi.expectSelectedItemToEqual(2, 'Application1');
        DipListOfCi.expectSelectedItemNotPresent(3);
        TestBindings.expectModelToEqual('["Item 1","Item 2","Item 4","Item 5","Application1"]');

        DipListOfCi.removeSelectedItem(2);
        DipListOfCi.expectSelectedItemToEqual(1, 'Item 1');
        DipListOfCi.expectSelectedItemNotPresent(2);
        TestBindings.expectModelToEqual('["Item 1","Item 2","Item 4","Item 5"]');
        DipListOfCi.clearFilter();

        DipListOfCi.expectSelectedItemToEqual(1, 'Item 1');
        DipListOfCi.expectSelectedItemToEqual(2, 'Item 2');
        DipListOfCi.expectSelectedItemToEqual(3, 'Item 4');
        DipListOfCi.expectSelectedItemToEqual(4, 'Item 5');
        DipListOfCi.expectSelectedItemNotPresent(5);
    });

    it('should disable elements in disabled mode but still allow to search', () => {
        DipListOfCi.expectEnabled();
        TestBindings.toggleDisabled();
        DipListOfCi.expectClearIconOfItemToBeNotPresent(1);
        DipListOfCi.expectFilterEnabled();
        DipListOfCi.expectDisabled();
        TestBindings.toggleDisabled();
        DipListOfCi.expectEnabled();
    });

    it('should properly render different view modes', () => {
        TestBindings.displayModeDisplay();
        DipListOfCi.expectClearIconOfItemToBeNotPresent(1);
        DipListOfCi.expectFilterEnabled();
        DipListOfCi.expectDisabled();
        TestBindings.displayModeCreation();
        DipListOfCi.expectClearIconOfItemToBePresent(1);
        DipListOfCi.expectFilterEnabled();
        DipListOfCi.expectEnabled();
        TestBindings.displayModeEdit();
        DipListOfCi.expectClearIconOfItemToBePresent(1);
        DipListOfCi.expectFilterEnabled();
        DipListOfCi.expectEnabled();
    });
});
